reflect: Reflect Columns in a Principal Component-like Object
Description
Principle component-like objects have variable loadings (the eigenvectors of the covariance/correlation matrix)
whose signs are arbitrary, in the sense that a given column can be
reflected (multiplied by -1) without changing the fit.
Usage
reflect(pcobj, columns = 1:2)
Value
The pca-like object with specified columns of the
variable loadings and observation scores multiplied
by -1.
This function allows one to reflect any columns of the variable
loadings (and corresponding observation scores). This is often
useful for interpreting a biplot, for example when a component (often the first) has all negative signs.